@@ -177,8 +177,7 @@ class BaseMenu:
         """Collects user input and places it into the input attribute."""
         try:
             message = await self.ctx.bot.wait_for('message', timeout=self.timeout,
-                                                  check=lambda m: m.author == self.ctx.author
-                                                  and self.ctx.channel == m.channel)
+                                                  check=self._check_message)
 
         except asyncio.TimeoutError:
             if self.page.on_timeout:
@@ -190,6 +189,10 @@ class BaseMenu:
         else:
             return message
 
+    def _check_message(self, m: Message) -> bool:
+        """Returns true if the author is the person who responded and the channel is the same."""
+        return m.author == self.ctx.author and self.ctx.channel == m.channel
+
     async def _validate_pages(self):
         """Checks that the Menu contains at least one Page."""
         if len(self.pages) <= 1:
