@@ -81,7 +81,7 @@ class Poll(ButtonMenu):
         while True:
             try:
                 reaction, user = await self.ctx.bot.wait_for('reaction_add', timeout=self.timeout,
-                                                             check=lambda _, u: u != self.ctx.bot.user)
+                                                             check=self._check_not_bot)
 
             except asyncio.TimeoutError:
                 return
@@ -95,7 +95,7 @@ class Poll(ButtonMenu):
         while True:
             try:
                 reaction, user = await self.ctx.bot.wait_for('reaction_remove', timeout=self.timeout,
-                                                             check=lambda _, u: u != self.ctx.bot.user)
+                                                             check=self._check_not_bot)
 
             except asyncio.TimeoutError:
                 return
@@ -108,6 +108,10 @@ class Poll(ButtonMenu):
         """Handles poll duration."""
         await asyncio.sleep(self.timeout)
 
+    def _check_not_bot(self, _, u: User) -> bool:
+        """Returns true if the user who reacted is not a bot."""
+        return u != self.ctx.bot.user
+
     async def _finish_poll(self):
         """Removes multi-votes and calls the Page on_next function when finished."""
         cheaters = await self._get_cheaters()
