@@ -22,19 +22,17 @@ class TextMenu(BaseMenu):
         self.data = data if data else {}
 
     def __repr__(self):
-        return f'<Menu pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, ' \
-               f'active={self.active} page={self.page_index}, data={self.data}>'
+        return f'TextMenu(pages={[p.__str__() for p in self.pages]}, timeout={self.timeout}, ' \
+               f'active={self.active} page={self.page_index}, data={self.data})'
 
     async def open(self):
         """The entry point to a new TextMenu instance; starts the main menu loop.
         Manages gathering user input, basic validation, sending messages, and cancellation requests."""
         await super()._validate_pages()
 
-        if not await super().validate_user():
+        if await self._start_session() is False:
             return
 
-        await super().set_user_active()
-
         self.output = await self.ctx.send(embed=self.page)
 
         _first_iteration = True
@@ -45,12 +43,14 @@ class TextMenu(BaseMenu):
             _first_iteration = False
 
             self.input = await self._get_input()
-            await self._cleanup_input()
 
-            if await self._is_cancelled():
-                return
+            if self.input:
+                await self._cleanup_input()
 
-            await self.page.on_next(self)
+                if await self._is_cancelled():
+                    return
+
+                await self.page.on_next(self)
 
     # Internal Methods
     async def _cleanup_input(self):
